@@ -48,8 +48,11 @@ class Domoticz(IPlugin):
 				bodies = rs['boy']
 				log.msg("BODIES  :  %s" % (bodies))
 				log.msg("on off  :  %s" % (on_off))
-				log.msg("number  :  %s" % (int(rs['idx'])))	
-				resp = requests.get ('http://192.168.0.3:8080/json.htm?type=command&param=switchlight&idx=%02d&switchcmd=%s&level=0' % (int(rs['idx']),on_off))
+				log.msg("number  :  %s" % (int(rs['idx'])))
+# resp = requests.get ('http://192.168.0.3:8080/json.htm?type=command&param=switchlight&idx=59&switchcmd=On&level=0')	
+				req = "'http://192.168.0.3:8080/json.htm?type=command&param=switchlight&idx=%02d&switchcmd=%s&level=0' % (int(rs['idx']),on_off)"
+				log.msg("resp  :  %s" % (rep))				
+				resp = requests.get (req)
 				log.msg("resp  :  %s" % (resp))
 		return {"plugin": "Domoticz",
 			"method": "switchlight",
